searchData={"items":[{"type":"module","title":"NervesLogging.KmsgParser","doc":"Functions for parsing kmsg strings","ref":"NervesLogging.KmsgParser.html"},{"type":"function","title":"NervesLogging.KmsgParser.parse/1","doc":"Parse out the kmsg facility, severity, and message (including the timestamp\nand host) from a kmsg-formatted string.\n\nSee https://elixir.bootlin.com/linux/latest/source/Documentation/ABI/testing/dev-kmsg for full details.\n\nMost messages are of the form:\n\n```text\npriority,sequence,timestamp,flag;message\n```\n\n`priority` is an integer that when broken apart gives you a facility and severity.\n`sequence` is a monotonically increasing counter\n`timestamp` is the time in microseconds\n`flag` is almost always `-`\n`message` is everything else\n\nThis parser only supports the minimum kmsg reports. The spec above describes\nmore functionality, but it appears to be uncommon and I haven't seen any\nexamples yet in my testing.","ref":"NervesLogging.KmsgParser.html#parse/1"},{"type":"module","title":"NervesLogging.KmsgTailer","doc":"Collects operating system-level messages from `/proc/kmsg`,\nforwarding them to `Logger` with an appropriate level to match the syslog\npriority parsed out of the message.","ref":"NervesLogging.KmsgTailer.html"},{"type":"function","title":"NervesLogging.KmsgTailer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NervesLogging.KmsgTailer.html#child_spec/1"},{"type":"function","title":"NervesLogging.KmsgTailer.start_link/1","doc":"Start the kmsg monitoring GenServer.","ref":"NervesLogging.KmsgTailer.html#start_link/1"},{"type":"module","title":"NervesLogging.SyslogParser","doc":"Functions for parsing syslog strings","ref":"NervesLogging.SyslogParser.html"},{"type":"function","title":"NervesLogging.SyslogParser.decode_priority/1","doc":"Decode a syslog priority to facility and severity","ref":"NervesLogging.SyslogParser.html#decode_priority/1"},{"type":"function","title":"NervesLogging.SyslogParser.parse/1","doc":"Parse out the syslog facility, severity, and message (including the timestamp\nand host) from a syslog-formatted string.\n\nThe message is of the form:\n\n```text\n message\n```\n\n`pri` is an integer that when broken apart gives you a facility and severity.\n`message` is everything else.","ref":"NervesLogging.SyslogParser.html#parse/1"},{"type":"type","title":"NervesLogging.SyslogParser.facility/0","doc":"","ref":"NervesLogging.SyslogParser.html#t:facility/0"},{"type":"type","title":"NervesLogging.SyslogParser.severity/0","doc":"","ref":"NervesLogging.SyslogParser.html#t:severity/0"},{"type":"module","title":"NervesLogging.SyslogTailer","doc":"This GenServer routes syslog messages from C-based applications and libraries through\nthe Elixir Logger for collection.","ref":"NervesLogging.SyslogTailer.html"},{"type":"function","title":"NervesLogging.SyslogTailer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NervesLogging.SyslogTailer.html#child_spec/1"},{"type":"function","title":"NervesLogging.SyslogTailer.start_link/1","doc":"Start the local syslog GenServer.","ref":"NervesLogging.SyslogTailer.html#start_link/1"},{"type":"extras","title":"NervesLogging","doc":"# NervesLogging\n\n[![CircleCI](https://circleci.com/gh/nerves-project/nerves_logging.svg?style=svg)](https://circleci.com/gh/nerves-project/nerves_logging)\n[![Hex version](https://img.shields.io/hexpm/v/nerves_logging.svg \"Hex version\")](https://hex.pm/packages/nerves_logging)\n[![REUSE status](https://api.reuse.software/badge/github.com/nerves-project/nerves_logging)](https://api.reuse.software/info/github.com/nerves-project/nerves_logging)\n\nNervesLogging forwards log messages from the Linux kernel and syslog to the\nElixir logger. It's used with Nerves so that all log messages pass through one\nplace.\n\nMessages logged by NervesLogging copy the \"Syslog\" severity directly to the\nLogger level. This means that if the kernel's level is \"Error\", the Elixir level\nwill be `:error`. Since Elixir 1.11 and later have the same log levels as\nSyslog, this mapping is 1:1.\n\nThe Syslog facility is passed via log metadata.\n\nSee the [Elixir Logger documentation](https://hexdocs.pm/logger/Logger.html) for\nreducing what's logged if the system logs become too noisy. For example, try\n`Logger.put_application_level(:nerves_logging, :error)`.","ref":"readme.html"},{"type":"extras","title":"Using - NervesLogging","doc":"There's no configuration. Add the following to a supervision tree to capture the\nlogs:\n\n```elixir\n    [NervesLogging.KmsgTailer, NervesLogging.SyslogTailer]\n```\n\nIf you're using Nerves, you don't need to do this.\n[Nerves.Runtime](https://github.com/nerves-project/nerves_runtime) adds these to\nits supervision tree.","ref":"readme.html#using"},{"type":"extras","title":"License - NervesLogging","doc":"All original source code in this project is licensed under Apache-2.0.\n\nAdditionally, this project follows the [REUSE recommendations](https://reuse.software)\nand labels so that licensing and copyright are clear at the file level.\n\nExceptions to Apache-2.0 licensing are:\n\n* Configuration and data files are licensed under CC0-1.0\n* Documentation is CC-BY-4.0","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.2 - 2023-11-05 - Changelog","doc":"* Changes\n  * Label log messages coming from syslog and the kernel ringbuffer as `$syslog`\n    and `$kmsg`. These are in the \"application\" field. This helps when log\n    messages by application since these used to be `nil`.","ref":"changelog.html#v0-2-2-2023-11-05"},{"type":"extras","title":"v0.2.1 - 2023-06-30 - Changelog","doc":"* Changes\n  * Fix Elixir 1.15 Logger warning","ref":"changelog.html#v0-2-1-2023-06-30"},{"type":"extras","title":"v0.2.0 - 2022-07-04 - Changelog","doc":"* Changes\n  * No longer automatically start log tailers. Users must add\n    `NervesLogging.KmsgTailer` and `NervesLogging.SyslogTailer` to their\n    supervision trees. This simplifies the logic for whether to start the\n    loggers or not. Very few users will need to do anything. It will be handled\n    by `Nerves.Runtime`.","ref":"changelog.html#v0-2-0-2022-07-04"},{"type":"extras","title":"v0.1.1 - 2022-06-03 - Changelog","doc":"* Changes\n  * Don't crash when lacking permissions to read logs. Restarting doesn't fix\n    the permission issue so this ends up being terminal. The error will be\n    logged.","ref":"changelog.html#v0-1-1-2022-06-03"},{"type":"extras","title":"v0.1.0 - 2022-04-26 - Changelog","doc":"Extract system logging from `nerves_runtime`.\n\n* Updates\n  * Require Elixir 1.11 and remove all syslog-to-Elixir log level conversion code\n    since Elixir accepts all of the syslog levels now.\n  * Remove the `:severity` field from log messages since it's redundant now.\n    It's unknown if this field was actually used.","ref":"changelog.html#v0-1-0-2022-04-26"}],"content_type":"text/markdown"}